@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3854 2010-11-21 12:06:30Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3879 2010-12-04 02:16:20Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -91,8 +91,11 @@ class ScriptLibInfo
 	const JQUERY_FACEBOX_FILENAME		= 'jquery/facebox.js';
 	const JQUERY_FACEBOX_CSS			= 'jquery/facebox.css';
 	const JQUERY_CURVYCORNERS_FILENAME	= 'jquery/jquery.curvycorners.packed.js';
+	/*
 	const JQUERY_PRETTYPHOTO_FILENAME	= 'jquery/jquery.prettyPhoto.js';
-	const JQUERY_PRETTYPHOTO_CSS		= 'jquery/prettyPhoto/css/prettyPhoto.css';
+	const JQUERY_PRETTYPHOTO_CSS		= 'jquery/prettyPhoto/css/prettyPhoto.css';*/
+const JQUERY_PRETTYPHOTO_FILENAME	= 'jquery/prettyphoto3.0.1/js/jquery.prettyPhoto.js';
+const JQUERY_PRETTYPHOTO_CSS		= 'jquery/prettyphoto3.0.1/css/prettyPhoto.css';
 	const JQUERY_QTIP_FILENAME			= 'jquery/jquery.qtip-1.0.min.js';
 	const JQUERY_CALCULATION_FILENAME	= 'jquery/jquery.calculation.js';
 	const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot/jquery.jqplot.min.js';
