@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 3809 2010-11-12 09:35:09Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 3842 2010-11-19 08:26:26Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -1214,6 +1214,35 @@ class BaseWidgetContainer extends Core
 			return date("y/m/d", $time);
 		}
 	}
+	/**
+	 * ロケールに対応した経過時間表記の文字列を作成
+	 *
+	 * @param int $time		経過時間(秒)
+	 * @param int $type		0=ロングフォーマット、1=ショートフォーマット(m,h,dのアルファベット表記)
+	 * @return string		変換後データ、初期化値のときは空文字列を返す
+	 */
+	function convertToDispPassageTime($time, $type = 0)
+	{
+		static $localeUnits;
+	
+		$values = array(60, 24, 1);
+		
+		if ($type == 0){		// ロングフォーマットのとき
+			if (!isset($localeUnits)) $localeUnits = explode(';', $this->_g('minute;hour;day'));
+			$unitArray = $localeUnits;
+		} else {
+			$unitArray = array('m', 'h', 'd');	// 分,時間,日
+		}
+		$time = $time / 60; // minutes
+
+		for ($i = 0; $i < count($units); $i++){
+			$value = $values[$i];
+			if ($time < $value) break;
+			$time /= $value;
+		}
+		$time = floor($time) . $unitArray[$i];
+		return $time;
+	}
 	/**
 	 * テキストデータを表示用のテキストに変換
 	 *
