@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: textConvManager.php 3767 2010-11-04 01:01:17Z fishbone $
+ * @version    SVN: $Id: textConvManager.php 3828 2010-11-16 06:20:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/htmlEdit.php');
@@ -265,8 +265,9 @@ class TextConvManager extends Core
 		$this->contentDt = $contentDt;
 		$dest = $src;
 		
+		// ### タグの削除 ###
 		// 表示しないタグを削除。データ量を減らす。
-		$removeTags = array('script', 'style', 'iframe', 'noframes?');
+		$removeTags = array('script', 'style', 'noframes?');
 		foreach ($removeTags as $value){
 			$dest = preg_replace('/<'.$value.'\b[^>]*?>.*?<\/'.$value.'\b[^>]*?>/si', '', $dest);
 		}
@@ -278,6 +279,11 @@ class TextConvManager extends Core
 		$dest = $this->deleteTag($dest, 'tfoot');
 		$dest = $this->deleteTag($dest, 'tr');
 		
+		// ### 他のタグへの変換 ###
+		// IFRAMEタグをAタグに変換
+		$str = '/<iframe\b(.*?)>(.*?)<\/iframe\b[^>]*?>/si';
+		$dest = preg_replace_callback($str, array($this, "_replace_iframe_callback"), $dest);
+		
 		// TH,TD,CAPTIONタグをDIVに変換
 /*		$dest = preg_replace('/<th\b[^>]*?>/si', '<div>', $dest);
 		$dest = preg_replace('/<\/th\b[^>]*?>/si', '</div>', $dest);
@@ -443,6 +449,20 @@ class TextConvManager extends Core
 		$dest = preg_replace_callback($str, array($this, '_replace_markquee_callback'), $dest);
 		return $dest;
 	}
+	/**
+	 * IFRAMEタグ変換コールバック関数
+	 *
+	 * @param array $matchData		検索マッチデータ
+	 * @return string				変換後データ
+	 */
+    function _replace_iframe_callback($matchData)
+	{
+		// URL、タイトルを取得
+		$url = $this->_getAttribute($matchData[1], 'src');
+		$name = $this->_getAttribute($matchData[1], 'name');
+		$destTag = '<a href="' . $url . '">' . $name . '</a>';
+		return $destTag;
+	}
 	/**
 	 * FONTタグ変換コールバック関数
 	 *
@@ -554,6 +574,27 @@ class TextConvManager extends Core
 
 		return preg_replace($search, $replace, $src);
 	}
+	/**
+	 * HTMLタグから指定属性の値を取得
+	 *
+	 * @param string $src	HTMLタグ
+	 * @param string $sttr	属性文字列
+	 * @param bool $isPlainText	エンティティ文字を元のテキストの変換するかどうか
+	 * @return string		属性の値
+	 */
+	function _getAttribute($src, $attr, $isPlainText = false)
+	{
+		$regex = '/'  . $attr . '\s*=\s*[\'"]+(.+?)[\'"]/si';
+		if (preg_match($regex, $src, $matches)){
+			if ($isPlainText){
+				return convertFromHtmlEntity($matches[1]);
+			} else {
+				return $matches[1];
+			}
+		} else {
+			return '';
+		}
+	}
 	/**
 	 * 画像の種別を取得
 	 *
