@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_base.sql 3519 2010-08-21 07:40:42Z fishbone $
+-- * @version    SVN: $Id: create_base.sql 3639 2010-09-27 09:54:19Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -292,6 +292,7 @@ CREATE TABLE _search_word (
     sw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     sw_word              TEXT                                         NOT NULL,      -- 検索キーワード
     sw_basic_word        TEXT                                         NOT NULL,      -- 比較用基本ワード
+    sw_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス
     sw_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェットID(ファイル名)
     sw_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     sw_client_id         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- PCの場合はアクセス管理用クッキー値。携帯の場合は端末ID「XX-xxxxxx」(XX=キャリアDC,AU,SB、xxxxxx=端末ID)。
@@ -529,6 +530,7 @@ CREATE TABLE _page_id (
     pg_type              INT            DEFAULT 0                     NOT NULL,      -- ページID種別(0=ページメインID,1=ページサブID)
     
     pg_default_sub_id    VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- デフォルトのサブページID(ページID種別がページメインIDとき使用)
+    pg_url               TEXT                                         NOT NULL,      -- アクセスURL(ページID種別がページメインIDとき使用)
     pg_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス(ページID種別がページメインIDとき使用)
     pg_class             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 起動クラス名(ページID種別がページメインIDとき使用)
     pg_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
@@ -559,6 +561,7 @@ CREATE TABLE _page_info (
     pn_meta_keywords     TEXT                                         NOT NULL,      -- METAタグ、検索用キーワード(個別)
     pn_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- メインコンテンツの種別(content=汎用コンテンツ、product=製品、bbs=掲示板、blog=ブログ、wiki=wikiコンテンツ)
     pn_auth_type         INT            DEFAULT 0                     NOT NULL,      -- アクセス制御タイプ(0=管理者のみ、1=制限なし、2=ログインユーザ)
+    pn_user_limited      BOOLEAN        DEFAULT false                 NOT NULL,      -- アクセス可能ユーザを制限
     pn_use_ssl           BOOLEAN        DEFAULT false                 NOT NULL,      -- SSLを使用するかどうか
     
     pn_checked_out       BOOLEAN        DEFAULT false                 NOT NULL,      -- チェックアウト中かどうか
@@ -729,6 +732,8 @@ CREATE TABLE _menu_def (
     md_type              INT            DEFAULT 0                     NOT NULL,      -- メニュー項目タイプ(0=リンク、1=フォルダ、2=テキスト、3=セパレータ)
     md_link_type         INT            DEFAULT 0                     NOT NULL,      -- リンクタイプ(0=同ウィンドウ、1=別ウィンドウ)
     md_link_url          TEXT                                         NOT NULL,      -- リンク先
+    md_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- リンク先のコンテンツの種別
+    md_content_id        VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- リンク先のコンテンツのID
     md_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
 
     md_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
