@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 3702 2010-10-15 11:02:23Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 3814 2010-11-13 06:57:00Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -112,7 +112,30 @@ INSERT INTO _nav_item
 (306,   300,          5,        'admin_menu', 'editmenu',        0,               '',       '管理メニュー編集',     '管理メニュー編集',     '管理機能のメインメニューを編集します。'),
 (399,   0,            3,        'admin_menu', '_399',            1,               '',       '改行',                 '',                     ''),
 (1100,  0,            11,       'admin_menu', '_others',         0,               '',       'その他',               '',                     ''),
-(1101,  1100,         0,        'admin_menu', 'logout',          0,               '',       'ログアウト',           'ログアウト',           '管理機能からログアウトします。');
+(1101,  1100,         0,        'admin_menu', 'logout',          0,               '',       'ログアウト',           'ログアウト',           '管理機能からログアウトします。'),
+(10100,   0,            0,        'admin_menu.en', '_page',           0,               '',       'Edit Page',             'Edit Page',             'Edit page for design and function.'),
+(10101,   10100,          0,        'admin_menu.en', 'pagedef',         0,               '',       'PC Page',         'PC Page',         'Edit page for PC.'),
+(10102,   10100,          1,        'admin_menu.en', 'pagedef_mobile',  0,               '',       'Mobile Page',       'Mobile Page',       'Edit page for Mobile.'),
+(10103,   10100,          2,        'admin_menu.en', 'pagedef_smartphone',  0,           '',       'Smartphone Page', 'Smartphone Page',       'Edit page for Smartphone.'),
+(10104,   10100,          3,        'admin_menu.en', 'widgetlist',      0,               '',       'Widget Administration',     'Widget Administration',     'Administrate widgets with widget config window.'),
+(10105,   10100,          4,        'admin_menu.en', 'templist',        0,               '',       'Template Administration',     'Template Administration',     'Administrate templates.'),
+(10106,   10100,          5,        'admin_menu.en', 'smenudef',        0,               '',       'Menu Administration', 'Menu Administration', 'Administrate menu definition.'),
+(10200,   0,            1,        'admin_menu.en', '_login',          0,               '',       'System Operation',         '',                     ''),
+(10201,   10200,          0,        'admin_menu.en', 'userlist',        0,               '',       'User List',           'User List',           'Administrate user to login.'),
+(10202,   10200,          1,        'admin_menu.en', 'loginstatus',     0,               '',       'Login Status',         'Login Status',         'View user login status.'),
+(10203,   10200,          2,        'admin_menu.en', 'analyzecalc',     0,               '',       'Access Analytics', 'Access Analytics', 'Analyze site access.'),
+(10204,   10200,          3,        'admin_menu.en', 'opelog',          0,               '',       'Operation Log',         'Operation Log',         'View system operation log.'),
+(10205,   10200,          4,        'admin_menu.en', 'accesslog',       0,               '',       'Access Log',     'Access Log',     'View site access log .'),
+(10300,   0,            2,        'admin_menu.en', '_config',         0,               '',       'System Administration',         '',                     ''),
+(10301,   10300,          0,        'admin_menu.en', 'configsite',      0,               '',       'Site Information',             'Site Information',             'Configure site information.'),
+(10302,   10300,          1,        'admin_menu.en', 'configsys',       0,               '',       'System Information',         'System Information',         'Configure sytem information.'),
+(10303,   10300,          2,        'admin_menu.en', 'resbrowse',       0,               '',       'Resource Browse',     'Resource Browse',     'Administrate resource files.'),
+(10304,   10300,          3,        'admin_menu.en', 'master',          0,               '',       'System Master', 'System Master', 'Administrate system master data.'),
+(10305,   10300,          4,        'admin_menu.en', 'initsystem',      0,               '',       'Database Maintenance',       'Database Maintenance',       'Database maintenance such as data initializing.'),
+(10306,   10300,          5,        'admin_menu.en', 'editmenu',        0,               '',       'Edit Administration Menu',     'Edit Administration Menu',     'Edit administration menu.'),
+(10399,   0,            3,        'admin_menu.en', '_399',            1,               '',       'Return',                 '',                     ''),
+(11100,  0,            11,       'admin_menu.en', '_others',         0,               '',       'Others',               '',                     ''),
+(11101,  11100,         0,        'admin_menu.en', 'logout',          0,               '',       'Logout',           'Logout',           'Logout from system.');
 
 -- ページIDマスター
 INSERT INTO _page_id 
