@@ -10,17 +10,17 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 2363 2009-09-26 14:45:44Z fishbone $
+ * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 2734 2009-12-25 05:51:56Z fishbone $
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_serverDb.php');
 
 class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
+	private $serverDb;		// DB接続オブジェクト
 	private $serialNo;	// シリアルNo
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
 	private $logLevelArray;				// 表示するログレベル
@@ -29,6 +29,9 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 	private $logStatus;					// 現在のログ表示ステータス
 	private $clientIp;			// クライアントのIPアドレス
 	private $browserIconFile;	// ブラウザアイコンファイル名
+	private $showMessage;		// メッセージ画面かどうか
+	private $message;			// 表示メッセージ
+	private $server;			// 指定サーバ
 	const DEFAULT_LIST_COUNT = 30;			// 最大リスト表示数
 	const MAX_PAGE_COUNT = 20;				// 最大ページ数
 	const INFO_ICON_FILE = '/images/system/info16.png';			// 情報アイコン
@@ -49,7 +52,7 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
+		$this->serverDb = new admin_serverDb();
 		
 		// ログレベルタイプ
 		$this->logLevelArray = array(	array(	'name' => 'すべて',		'value' => '0'),
@@ -125,6 +128,26 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{
+		// サーバ指定されている場合は接続先DBを変更
+		$this->server = $request->trimValueOf(M3_REQUEST_PARAM_SERVER);
+		if (!empty($this->server)){
+			// 設定データを取得
+			$ret = $this->serverDb->getServerById($this->server, $row);
+			if ($ret){
+				$dbDsn = $row['ts_db_connect_dsn'];		// DB接続情報
+				$dbAccount = $row['ts_db_account'];	// DB接続アカウント
+				$dbPassword = $row['ts_db_password'];// DB接続パスワード
+
+				// テスト用DBオブジェクト作成
+				$ret = $this->db->openLocalDb($dbDsn, $dbAccount, $dbPassword);// 接続先を変更
+			}
+			if (!$ret){		// サーバに接続できない場合
+				$this->showMessage = true;		// メッセージ画面かどうか
+				$this->message = 'サーバに接続できません';
+				return 'message.tmpl.html';
+			}
+		}
+		
 		$task = $request->trimValueOf('task');
 		if ($task == 'opelog_detail'){		// 詳細画面
 			return 'opelog_detail.tmpl.html';
@@ -143,6 +166,10 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
+		if ($this->showMessage){		// メッセージ画面かどうか
+			$this->setMsg(self::MSG_APP_ERR, $this->message);
+			return;
+		}
 		$task = $request->trimValueOf('task');
 		if ($task == 'opelog_detail'){	// 詳細画面
 			return $this->createDetail($request);
@@ -232,6 +259,11 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("search_range", "end_no", $endNo);
 		if ($totalCount > 0) $this->tmpl->setAttribute('search_range', 'visibility', 'visible');// 検出範囲を表示
 		
+		// アクセスログURL
+		$accessLogUrl = '?task=accesslog_detail&openby=simple';
+		if (!empty($this->server)) $accessLogUrl .= '&_server=' . $this->server;
+		$this->tmpl->addVar("_widget", "access_log_url", $accessLogUrl);
+		
 		// 運用ログを取得
 		$this->db->getOpeLogList($viewLevel, $this->logStatus, $viewCount, $pageNo, array($this, 'logListLoop'));
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
@@ -312,6 +344,11 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "detail", $this->convertToDispString($logMsgDetail));
 		$this->tmpl->addVar("_widget", "access_log_serial", $accessLog);
 		$this->tmpl->addVar("_widget", "time", $time);
+		
+		// アクセスログURL
+		$accessLogUrl = '?task=accesslog_detail&openby=simple';
+		if (!empty($this->server)) $accessLogUrl .= '&_server=' . $this->server;
+		$this->tmpl->addVar("_widget", "access_log_url", $accessLogUrl);
 
 		// 一覧の表示条件
 		$this->tmpl->addVar("_widget", "page", $page);	// ページ番号
@@ -320,6 +357,12 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "log_status", $logStatus);	// ログ表示ステータス
 		
 		$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 更新ボタン表示
+		
+		// サーバ指定の場合は更新ボタンを使用不可に設定
+		if (!empty($this->server)){
+			$this->tmpl->addVar("_widget", "msg_disabled", 'disabled');
+			$this->tmpl->addVar("update_button", "update_disabled", 'disabled');
+		}
 	}
 	/**
 	 * 運用ログ一覧取得したデータをテンプレートに設定する
