@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainSmenudefWidgetContainer.php 3407 2010-07-20 05:05:44Z fishbone $
+ * @version    SVN: $Id: admin_mainSmenudefWidgetContainer.php 3838 2010-11-17 08:09:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -67,19 +67,19 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 	{
 		$task = $request->trimValueOf('task');
 		
-		if (version_compare(M3_SYSTEM_VERSION, '1.15.0') >= 0){			// jQuery v1.4対応版
+		/*if (version_compare(M3_SYSTEM_VERSION, '1.15.0') >= 0){			// jQuery v1.4対応版
 			if ($task == 'smenudef_detail'){		// 詳細画面
 				return 'smenudef_detail.tmpl.html';
 			} else {			// 一覧画面
 				return 'new/smenudef.tmpl.html';
 			}
-		} else {
+		} else {*/
 			if ($task == 'smenudef_detail'){		// 詳細画面
 				return 'smenudef_detail.tmpl.html';
 			} else {			// 一覧画面
 				return 'smenudef.tmpl.html';
 			}
-		}
+		//}
 	}
 	/**
 	 * テンプレートにデータ埋め込む
