@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3871 2010-12-01 10:08:24Z fishbone $
+ * @version    SVN: $Id: index.php 3873 2010-12-02 07:16:26Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -87,30 +87,6 @@ $HELP['userlist_del_btn']['body'] = '選択されているユーザを削除し
 $HELP['userlist_ret_btn']['title'] = '戻るボタン';
 $HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
 
-// ########## テンプレート一覧 ##########
-$HELP['templist']['title'] = 'テンプレート一覧';
-$HELP['templist']['body'] = 'システムで利用可能なテンプレートの一覧です。テンプレートのインストールはこの画面の最下部の「テンプレートアップロード」から行います。';
-$HELP['templist_type']['title'] = 'テンプレートタイプ';
-$HELP['templist_type']['body'] = 'PC用のテンプレートか携帯用のテンプレートかを選択します。';
-$HELP['templist_install_dir']['title'] = 'テンプレートインストールディレクトリ';
-$HELP['templist_install_dir']['body'] = 'テンプレートのインストールディレクトリです。この配下に「テンプレートID」のディレクトリ名で個々のテンプレートが格納されます。';
-$HELP['templist_id']['title'] = 'ID';
-$HELP['templist_id']['body'] = 'テンプレートのIDです。テンプレートのディレクトリ名と同一です。';
-$HELP['templist_name']['title'] = '名前';
-$HELP['templist_name']['body'] = 'テンプレートの名前です。';
-$HELP['templist_format']['title'] = '形式';
-$HELP['templist_format']['body'] = 'テンプレートの形式です。<br />利用可能な形式は以下の通りです。Magic3では現在J15を標準としています。<br />●J10<br />Joomla! v1.0用テンプレート<br />●J15<br />Joomla! v1.5用テンプレート';
-$HELP['templist_default']['title'] = 'デフォルト';
-$HELP['templist_default']['body'] = '現在システムで選択されているデフォルトのテンプレートを示します。';
-$HELP['templist_act']['title'] = '操作';
-$HELP['templist_act']['body'] = '各種操作を行います。<br />●プレビュー<br />テンプレートがプレビューできます。<br />●更新<br />この一覧で変更した値を保存します。<br />●削除<br />テンプレートをシステムから削除します。<br />●ダウンロード<br />テンプレートをZIP圧縮形式でダウンロードします。このファイルはそのまま「テンプレートアップロード」からシステムへインストールできる形式です。';
-$HELP['templist_upload']['title'] = 'テンプレートアップロード';
-$HELP['templist_upload']['body'] = 'ZIP形式のテンプレートファイルをアップロードし、システムにテンプレートをインストールします。同じIDのテンプレートがすでに存在する場合はエラーになります。';
-$HELP['templist_detail_check']['title'] = '詳細表示';
-$HELP['templist_detail_check']['body'] = 'チェックを入れると一覧が詳細表示できます。';
-$HELP['templist_reload_dir_btn']['title'] = 'ディレクトリ再読み込み';
-$HELP['templist_reload_dir_btn']['body'] = 'テンプレートディレクトリを再読み込みして、一覧に表示されていないテンプレートを自動的にインストールします。';
-
 // ########## テーブルデータ編集 ##########
 $HELP['edittable_new_btn']['title'] = '新規ボタン';
 $HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
