@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: custom_searchWidgetContainer.php 3525 2010-08-24 05:32:45Z fishbone $
+ * @version    SVN: $Id: custom_searchWidgetContainer.php 3536 2010-08-27 08:25:52Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -131,7 +131,7 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 				$this->db->writeKeywordLog($cid, $this->gEnv->getCurrentWidgetId(), $keyword, $basicWord);
 				*/
 				// 検索キーワードを記録
-				$this->gInstance->getAnalyzeManager()->logKeyword($this->gEnv->getCurrentWidgetId(), $keyword);
+				$this->gInstance->getAnalyzeManager()->logSearchWord($this->gEnv->getCurrentWidgetId(), $keyword);
 			}
 			
 			// カテゴリの設定値を取得
